"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calibrateX = calibrateX;
const ml_gsd_1 = require("ml-gsd");
const ml_spectra_processing_1 = require("ml-spectra-processing");
/**
 * Filter that allows to calibrateX the x axis based on the presence of peaks
 * @param data
 * @param options
 */
function calibrateX(data, options = {}) {
    const { targetX = 0, nbPeaks = 1, from = data.x[0], to = data.x.at(-1), gsd: gsdOptions = {
        minMaxRatio: 0.1,
        realTopDetection: true,
        smoothY: true,
        sgOptions: {
            windowSize: 7,
            polynomial: 3,
        },
    }, } = options;
    const fromIndex = (0, ml_spectra_processing_1.xFindClosestIndex)(data.x, from);
    const toIndex = (0, ml_spectra_processing_1.xFindClosestIndex)(data.x, to);
    const peaks = (0, ml_gsd_1.gsd)({
        x: data.x.subarray(fromIndex, toIndex),
        y: data.y.subarray(fromIndex, toIndex),
    }, gsdOptions)
        .sort((a, b) => b.y - a.y)
        .slice(0, nbPeaks);
    if (peaks.length < nbPeaks)
        return { data };
    const middle = (0, ml_spectra_processing_1.xMean)(peaks.map((peak) => peak.x));
    return { data: { x: (0, ml_spectra_processing_1.xAdd)(data.x, targetX - middle), y: data.y } };
}
//# sourceMappingURL=calibrateX.js.map